@@ -1,5 +1,5 @@
 package CPAN::Testers::API;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 # ABSTRACT: REST API for CPAN Testers data
 
 #pod =head1 SYNOPSIS
@@ -24,8 +24,10 @@ our $VERSION = '0.002';
 
 use Mojo::Base 'Mojolicious';
 use CPAN::Testers::API::Base;
-use File::Share qw( dist_file );
+use File::Share qw( dist_dir dist_file );
 use Log::Any::Adapter;
+use Alien::SwaggerUI;
+use File::Spec::Functions qw( catdir catfile );
 
 #pod =method schema
 #pod
@@ -52,12 +54,28 @@ has schema => sub {
 #pod =cut
 
 sub startup ( $app ) {
+    unshift @{ $app->renderer->paths },
+        catdir( dist_dir( 'CPAN-Testers-API' ), 'templates' );
+    unshift @{ $app->static->paths },
+        catdir( dist_dir( 'CPAN-Testers-API' ), 'public' );
+
     $app->plugin( OpenAPI => {
         url => dist_file( 'CPAN-Testers-API' => 'api.json' ),
         allow_invalid_ref => 1,
     } );
     $app->helper( schema => sub { shift->app->schema } );
     $app->helper( render_error => \&render_error );
+
+    $app->routes->get( '/' => 'index' );
+    $app->routes->get( '/docs/*path' => { path => 'index.html' } )->to(
+        cb => sub {
+            my ( $c ) = @_;
+            my $path = catfile( Alien::SwaggerUI->root_dir, $c->stash( 'path' ) );
+            my $file = Mojo::Asset::File->new( path => $path );
+            $c->reply->asset( $file );
+        },
+    );
+
     Log::Any::Adapter->set( 'MojoLog', logger => $app->log );
 }
 
@@ -78,7 +96,10 @@ sub startup ( $app ) {
 #pod
 #pod     {
 #pod         "errors":  [
-#pod             { "message": 'Bad Request' }
+#pod             {
+#pod                 "path": "/",
+#pod                 "message": "Bad Request"
+#pod             }
 #pod         ]
 #pod     }
 #pod
@@ -98,7 +119,7 @@ sub render_error( $c, $status, @errors ) {
         status => $status,
         openapi => {
             errors => [
-                map { !ref $_ ? { message => $_ } : $_ } @errors,
+                map { !ref $_ ? { message => $_, path => '/' } : $_ } @errors,
             ],
         },
     );
@@ -116,7 +137,7 @@ CPAN::Testers::API - REST API for CPAN Testers data
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -163,7 +184,10 @@ The resulting JSON looks like so:
 
     {
         "errors":  [
-            { "message": 'Bad Request' }
+            {
+                "path": "/",
+                "message": "Bad Request"
+            }
         ]
     }
 
